import { h } from "@stencil/core";
export class AnalogClock {
    constructor() {
        this.size = undefined;
        this.timeZone = 0;
        this.time = Date.now();
    }
    componentDidLoad() {
        this.timer = window.setInterval(() => {
            this.time = Date.now();
        }, 250);
    }
    disconnectedCallback() {
        clearInterval(this.timer);
    }
    get hour() {
        return new Date(this.time).getHours();
    }
    get minute() {
        return new Date(this.time).getMinutes();
    }
    get second() {
        return new Date(this.time).getSeconds();
    }
    hourToDegrees() {
        const hour = this.hour + this.timeZone;
        return Math.floor(this.minute / 2) + hour * 30;
    }
    minuteToDegrees() {
        return Math.floor(this.second / 10) + this.minute * 6;
    }
    secondToDegrees() {
        return this.second * 6;
    }
    render() {
        return (h("svg", { key: '39e3465d3bf04035966b00bb15186d1f712163cd', class: "clock", viewBox: "0 0 200 200", width: this.size, height: this.size }, h("circle", { key: 'e4c4288aa0efc9cf98027eef1f5bd7c550c23a18', id: "circle", cx: "100", cy: "100", r: "95", "stroke-width": "10", fill: "transparent" }), h("line", { key: '296fb8ac19749103439f2ce1878db5ccfb214c20', id: "hour", transform: `rotate(${this.hourToDegrees()}, 100, 100)`, x1: "100", y1: "100", x2: "100", y2: "60", "stroke-width": "10", "stroke-linecap": "round" }), h("line", { key: 'acbe2c6ebdf05ff46e06144839dec43c45e8b40d', id: "minute", transform: `rotate(${this.minuteToDegrees()}, 100, 100)`, x1: "100", y1: "100", x2: "100", y2: "30", "stroke-width": "8", "stroke-linecap": "round" }), h("line", { key: 'f275abf7169379b2f61c9cdd185068f5e2373d4a', id: "second", transform: `rotate(${this.secondToDegrees()}, 100, 100)`, x1: "100", y1: "100", x2: "100", y2: "20", "stroke-width": "2", "stroke-linecap": "round" })));
    }
    static get is() { return "analog-clock"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["analog-clock.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["analog-clock.css"]
        };
    }
    static get properties() {
        return {
            "size": {
                "type": "number",
                "attribute": "size",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "undefined"
            },
            "timeZone": {
                "type": "number",
                "attribute": "time-zone",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "0"
            }
        };
    }
    static get states() {
        return {
            "time": {}
        };
    }
}
